@@ -1,6 +1,7 @@
 from starlette.applications import Starlette
 from starlette.middleware import Middleware
 from starlette.middleware.sessions import SessionMiddleware
+from starlette.middleware.cors import CORSMiddleware
 from starlette.middleware.authentication import AuthenticationMiddleware
 from starlette.authentication import AuthCredentials, AuthenticationBackend, AuthenticationError, SimpleUser, requires
 from starlette.middleware.httpsredirect import HTTPSRedirectMiddleware
@@ -18,3 +19,6 @@ from starlette.config import Config
 from starlette.datastructures import CommaSeparatedStrings, Secret, UploadFile, URLPath
 from starlette.types import ASGIApp, Receive, Scope, Send
 from starlette.concurrency import run_in_threadpool
+from starlette.background import BackgroundTask, BackgroundTasks
+from starlette.websockets import WebSocketDisconnect
+
